/* Actions.cs
   Copyright (C) 2006 Pageflex and Bitstream Inc. All rights reserved.

History:
  08.30.2006 rm   Created.
*/

using System;
using Pageflex.Scripting;
using Pageflex.Scripting.Exceptions;
//using System.Data.OleDb;
//using System.Data;
//using System.IO;


public class Actions
{
    // Increase or decrease font size of currently-selected text
    static public void BumpFontSize(string fontSizeDelta)
    {
        //System.Diagnostics.Debugger.Break();

        // If we hit an error we'll want to undo any changes, so start an undo section
        Document doc = Application.CurrentDocument;
        doc.BeginUndoSection(null);

        Range range = null;
        string message = "";
        if (Application.SelectedRange != null)
        {
            // Text is selected, so use it
            range = Application.SelectedRange;
        }
        else if (Application.SelectedShapes.Length == 1 &&
                 Application.SelectedShapes[0] is ITextContainer)
        {
            // A text container is selected, so use its text
            range = ((ITextContainer)Application.SelectedShapes[0]).Contents;
        }
        else
            message = "Please select some text or a text container.";

        if (range != null)
        {
            try
            {
                // The selected range may have different font sizes, so handle each separately
                foreach (Range subrange in range.ContentRanges)
                    subrange.FontSize += fontSizeDelta;
            }
            catch (InvalidMeasurementException)
            {
                message = "Could not parse fontSizeDelta. Use a number with units, such as '2pt'.";
            }
            catch (ValueTooSmallException)
            {
                message = "Cannot decrease font size lower than 0.1pt.";
            }
        }
        doc.EndUndoSection();

        // Inform client of error message via a user string
        Application.SetUserString("DocumentActionError", message, false);

        if (message != "")
            // Undo any changes we made
            doc.Undo();
    }

     static public void SetGridColors(string AreaTemplateName)
    {
        // Find all images in document
		try
		{
			Variable var = Application.GetVariable("Avdelingsnavn");
			Document doc = Application.CurrentDocument;
			Element e = doc.FindElement(AreaTemplateName);
			int index = 0;
			string color1 = "";
			string color2 = "";
			if (var.Value == "Telenor") //Telenor
			{
				color1 = "Telenor1";
				color2 = "Telenor2";
			}
			else if (var.Value == "djuice") //DJUICE
			{
				color1 = "DJUICE1";
				color2 = "DJUICE2";
			}
			Element sentinelElement = e.NextNonDescendantElementInTree;
			for (Element n = e; n != sentinelElement; n = n.NextElementInTree)
			{
				if (n is AreaTemplate)
				{
					AreaTemplate i = (AreaTemplate)n;
					if (i.IsVisible && i.Name != AreaTemplateName)
					{
						if (index % 2 == 0)
							i.FillColor = color1;
						else
							i.FillColor = color2;
						index++;
					}
				}
			}
		}
		catch (ElementNotFoundException ex)
		{
			Application.Log(ex.Message);
		}
    }

    static public void AddSize()
    {
        double[] arrSizes = { 71, 107, 144, 181, 218, 254, 291, 365 };
        Document doc = Application.CurrentDocument;
        foreach (double newSize in arrSizes)
        {
            doc.PageHeight = new Measurement(newSize, Measurement.Units.Mm);
            ITextContainer[] arrTextContainer = doc.OverflowingTextContainers;
            if (arrTextContainer.Length == 0)
            {
                break;
            }
        }
    }
    static public void ChangeSize()
    {
		Variable varWIDTH = Application.GetVariable("WIDTH");
		Variable varHEIGHT = Application.GetVariable("HEIGHT");
		double dblWidth = double.Parse(varWIDTH.Value);
		double dblHeight = double.Parse(varHEIGHT.Value);
        Document doc = Application.CurrentDocument;
        doc.PageHeight = new Measurement(dblHeight, Measurement.Units.Mm);
        doc.PageWidth = new Measurement(dblWidth, Measurement.Units.Mm);
    }

    // Add a page based on a SourcePage (page number)
    static public void AddPage(string sourcePage)
    {
        //System.Diagnostics.Debugger.Break();

        // If we hit an error we'll want to undo any changes, so start an undo section
        string[] arrArgs = sourcePage.Split('|');
        string masterPage = arrArgs[0]; // e.g: Master_B
        string currentPage = arrArgs[1]; //e.g: 4
        Document doc = Application.CurrentDocument;
        Page pageCurrent = (Page)doc.GetPage(uint.Parse(currentPage));
        //Page pageSibling = (Page)doc.GetPage(uint.Parse(currentPage) + 1);
        //Element parent = pageCurrent.ParentElement;
        //Element sibling = pageCurrent.NextSiblingElement;
        //Page sourceElement = doc.GetPage(sourcePage);
        //pageCurrent.Delete();
        Page newPage = new Page(masterPage);
        //Page newPage2 = (Page)newPage.Duplicate();
        //newPage.MoveBefore(pageCurrent.ParentElement, pageCurrent.NextSiblingElement);
        //Application.MergeData();

        doc.UpdateTablesOfContents();

    }

    static public void DeletePage(string currentPage)
    {
        //System.Diagnostics.Debugger.Break();

        // If we hit an error we'll want to undo any changes, so start an undo section
        Document doc = Application.CurrentDocument;
        Page pageCurrent = (Page)doc.GetPage(uint.Parse(currentPage));
        pageCurrent.Delete();

        doc.UpdateTablesOfContents();

    }

    static public void SetBackColor(string backgroundcolor, string AreaTemplateName )
    {
        //System.Diagnostics.Debugger.Break();

        // If we hit an error we'll want to undo any changes, so start an undo section
        Document doc = Application.CurrentDocument;
        Element e = doc.FindElement(AreaTemplateName);
	((AreaTemplate)e).FillColor=backgroundcolor;
        Application.Log(((AreaTemplate)e).Name);
        Application.Log(((AreaTemplate)e).FillColor);


    }

    static public void SetTextColor(string textcolor, string TextFrameName )
    {
        //System.Diagnostics.Debugger.Break();

        // If we hit an error we'll want to undo any changes, so start an undo section
        Document doc = Application.CurrentDocument;
        Element e = doc.FindElement(TextFrameName);
        if (e != null)
        	((TextFrame)e).Contents.TextColor = textcolor;
    }

static public void SetTextColorVar(string TextFrameName )
    {
        // Find all texframes in document
		Variable var = Application.GetVariable("COLOR");
        Document doc = Application.CurrentDocument;
		Element e = doc.FindElement(TextFrameName);
				if (e != null)
        	((TextFrame)e).Contents.TextColor = var.Value;
        
    }
}
